@@ -46,9 +46,9 @@ public:
 private:
     void slotOkClicked();
     void slotDefaultClicked();
-    GrantleeThemeEditor::ConfigureWidget *mConfigureWidget;
-    KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate;
-    Akonadi::AkonadiContactEditor *mDefaultContact;
+    GrantleeThemeEditor::ConfigureWidget *mConfigureWidget = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate = nullptr;
+    Akonadi::AkonadiContactEditor *mDefaultContact = nullptr;
 };
 
 #endif
