@@ -22,8 +22,7 @@
 
 #include <QStringList>
 
-namespace DefaultCompletion
-{
+namespace DefaultCompletion {
 QStringList defaultCompetion();
 QStringList defaultOptions();
 }
