@@ -22,8 +22,7 @@
 #include "grantleethemeeditor_export.h"
 #include <QDialog>
 
-namespace GrantleeThemeEditor
-{
+namespace GrantleeThemeEditor {
 class ManageThemesPrivate;
 class GRANTLEETHEMEEDITOR_EXPORT ManageThemes : public QDialog
 {
