@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -95,10 +95,6 @@ QStringList DefaultCompletion::defaultCompetion()
 
 QStringList DefaultCompletion::defaultOptions()
 {
-    QStringList lst;
-    lst << QStringLiteral("showlink")
-        << QStringLiteral("nameonly")
-        << QStringLiteral("safe")
-        << QStringLiteral("expandable");
+    const QStringList lst = {QStringLiteral("showlink"), QStringLiteral("nameonly"), QStringLiteral("safe"), QStringLiteral("expandable")};
     return lst;
 }
